@@ -78,7 +78,7 @@ TEST: {
     );
     my $mt = Text::MicroTemplate::Extended->new(
         include_path => [$path],
-        cache        => 2,
+        use_cache    => 2,
     );
     my $tt = Template->new(
         INCLUDE_PATH => [$path],
